==> zio-aws-groundstation_3-5.17.166.2-sources.jar: zio/aws/groundstation/model/ListContactsResponse.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListContactsResponse(
    contactList: Optional[Iterable[zio.aws.groundstation.model.ContactData]] =
      Optional.Absent,
    nextToken: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.ListContactsResponse = {
    import ListContactsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.ListContactsResponse
      .builder()
      .optionallyWith(
        contactList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.contactList)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.ListContactsResponse.ReadOnly =
    zio.aws.groundstation.model.ListContactsResponse.wrap(buildAwsValue())
}
object ListContactsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.ListContactsResponse =
      zio.aws.groundstation.model.ListContactsResponse(
        contactList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def contactList
        : Optional[List[zio.aws.groundstation.model.ContactData.ReadOnly]]
    def nextToken: Optional[String]
    def getContactList: ZIO[Any, AwsError, List[
      zio.aws.groundstation.model.ContactData.ReadOnly
    ]] = AwsError.unwrapOptionField("contactList", contactList)
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ) extends zio.aws.groundstation.model.ListContactsResponse.ReadOnly {
    override val contactList
        : Optional[List[zio.aws.groundstation.model.ContactData.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contactList())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.groundstation.model.ContactData.wrap(item)
          }.toList
        )
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ): zio.aws.groundstation.model.ListContactsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-groundstation_3-6.20.115.1-sources.jar: zio/aws/groundstation/model/ListContactsResponse.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.PaginationToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListContactsResponse(
    contactList: Optional[Iterable[zio.aws.groundstation.model.ContactData]] =
      Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.ListContactsResponse = {
    import ListContactsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.ListContactsResponse
      .builder()
      .optionallyWith(
        contactList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.contactList)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.ListContactsResponse.ReadOnly =
    zio.aws.groundstation.model.ListContactsResponse.wrap(buildAwsValue())
}
object ListContactsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.ListContactsResponse =
      zio.aws.groundstation.model.ListContactsResponse(
        contactList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def contactList
        : Optional[List[zio.aws.groundstation.model.ContactData.ReadOnly]]
    def nextToken: Optional[PaginationToken]
    def getContactList: ZIO[Any, AwsError, List[
      zio.aws.groundstation.model.ContactData.ReadOnly
    ]] = AwsError.unwrapOptionField("contactList", contactList)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ) extends zio.aws.groundstation.model.ListContactsResponse.ReadOnly {
    override val contactList
        : Optional[List[zio.aws.groundstation.model.ContactData.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.contactList())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.groundstation.model.ContactData.wrap(item)
          }.toList
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value =>
        zio.aws.groundstation.model.primitives.PaginationToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.ListContactsResponse
  ): zio.aws.groundstation.model.ListContactsResponse.ReadOnly = new Wrapper(
    impl
  )
}
